<?php

namespace Assetdocs\Manufacturer\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Assetdocs\Manufacturer\Http\Requests\ManufacturerAdminApiRequest;
use Assetdocs\Manufacturer\Interfaces\ManufacturerRepositoryInterface;
use Assetdocs\Manufacturer\Models\Manufacturer;

/**
 * Admin API controller class.
 */
class ManufacturerAdminApiController extends BaseController
{
    /**
     * The authentication guard that should be used.
     *
     * @var string
     */
    protected $guard = 'admin.api';

    /**
     * Initialize manufacturer controller.
     *
     * @param type ManufacturerRepositoryInterface $manufacturer
     *
     * @return type
     */
    public function __construct(ManufacturerRepositoryInterface $manufacturer)
    {
        $this->middleware('api');
        $this->middleware('jwt.auth:admin.api');
        $this->setupTheme(config('theme.themes.admin.theme'), config('theme.themes.admin.layout'));

        $this->repository = $manufacturer;
        parent::__construct();
    }

    /**
     * Display a list of manufacturer.
     *
     * @return json
     */
    public function index(ManufacturerAdminApiRequest $request)
    {
        $manufacturers  = $this->repository
            ->pushCriteria(new \Assetdocs\Manufacturer\Repositories\Criteria\ManufacturerAdminCriteria())
            ->setPresenter('\\Assetdocs\\Manufacturer\\Repositories\\Presenter\\ManufacturerListPresenter')
            ->scopeQuery(function($query){
                return $query->orderBy('id','DESC');
            })->all();
        $manufacturers['code'] = 2000;
        return response()->json($manufacturers) 
                         ->setStatusCode(200, 'INDEX_SUCCESS');

    }

    /**
     * Display manufacturer.
     *
     * @param Request $request
     * @param Model   Manufacturer
     *
     * @return Json
     */
    public function show(ManufacturerAdminApiRequest $request, Manufacturer $manufacturer)
    {
        $manufacturer         = $manufacturer->presenter();
        $manufacturer['code'] = 2001;
        return response()->json($manufacturer)
                         ->setStatusCode(200, 'SHOW_SUCCESS');;

    }

    /**
     * Show the form for creating a new manufacturer.
     *
     * @param Request $request
     *
     * @return json
     */
    public function create(ManufacturerAdminApiRequest $request, Manufacturer $manufacturer)
    {
        $manufacturer         = $manufacturer->presenter();
        $manufacturer['code'] = 2002;
        return response()->json($manufacturer)
                         ->setStatusCode(200, 'CREATE_SUCCESS');

    }

    /**
     * Create new manufacturer.
     *
     * @param Request $request
     *
     * @return json
     */
    public function store(ManufacturerAdminApiRequest $request)
    {
        try {
            $attributes             = $request->all();
            $attributes['user_id']  = user_id('admin.api');
            $manufacturer          = $this->repository->create($attributes);
            $manufacturer          = $manufacturer->presenter();
            $manufacturer['code']  = 2004;

            return response()->json($manufacturer)
                             ->setStatusCode(201, 'STORE_SUCCESS');
        } catch (Exception $e) {
            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 4004,
            ])->setStatusCode(400, 'STORE_ERROR');
;
        }
    }

    /**
     * Show manufacturer for editing.
     *
     * @param Request $request
     * @param Model   $manufacturer
     *
     * @return json
     */
    public function edit(ManufacturerAdminApiRequest $request, Manufacturer $manufacturer)
    {
        $manufacturer         = $manufacturer->presenter();
        $manufacturer['code'] = 2003;
        return response()-> json($manufacturer)
                        ->setStatusCode(200, 'EDIT_SUCCESS');;
    }

    /**
     * Update the manufacturer.
     *
     * @param Request $request
     * @param Model   $manufacturer
     *
     * @return json
     */
    public function update(ManufacturerAdminApiRequest $request, Manufacturer $manufacturer)
    {
        try {

            $attributes = $request->all();

            $manufacturer->update($attributes);
            $manufacturer         = $manufacturer->presenter();
            $manufacturer['code'] = 2005;

            return response()->json($manufacturer)
                             ->setStatusCode(201, 'UPDATE_SUCCESS');


        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 4005,
            ])->setStatusCode(400, 'UPDATE_ERROR');

        }
    }

    /**
     * Remove the manufacturer.
     *
     * @param Request $request
     * @param Model   $manufacturer
     *
     * @return json
     */
    public function destroy(ManufacturerAdminApiRequest $request, Manufacturer $manufacturer)
    {

        try {

            $t = $manufacturer->delete();

            return response()->json([
                'message'  => trans('messages.success.delete', ['Module' => trans('manufacturer::manufacturer.name')]),
                'code'     => 2006
            ])->setStatusCode(202, 'DESTROY_SUCCESS');

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 4006,
            ])->setStatusCode(400, 'DESTROY_ERROR');
        }
    }
}
