<?php

namespace Assetdocs\Manufacturer\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Form;
use Assetdocs\Manufacturer\Http\Requests\ManufacturerAdminWebRequest;
use Assetdocs\Manufacturer\Interfaces\ManufacturerRepositoryInterface;
use Assetdocs\Manufacturer\Models\Manufacturer;

/**
 * Admin web controller class.
 */
class ManufacturerAdminController extends BaseController
{
    /**
     * The authentication guard that should be used.
     *
     * @var string
     */
    protected $guard = 'admin.web';

    /**
     * Initialize manufacturer controller.
     *
     * @param type ManufacturerRepositoryInterface $manufacturer
     *
     * @return type
     */
    public function __construct(ManufacturerRepositoryInterface $manufacturer)
    {
        $this->middleware('web');
        $this->middleware('auth:admin.web');
        $this->setupTheme(config('theme.themes.admin.theme'), config('theme.themes.admin.layout'));

        $this->repository = $manufacturer;
        parent::__construct();
    }

    /**
     * Display a list of manufacturer.
     *
     * @return Response
     */
    public function index(ManufacturerAdminWebRequest $request)
    {
        $pageLimit = $request->input('pageLimit');
        if ($request->wantsJson()) {
            $manufacturers  = $this->repository
            ->pushCriteria(new \Assetdocs\Manufacturer\Repositories\Criteria\ManufacturerAdminCriteria())
                ->setPresenter('\\Assetdocs\\Manufacturer\\Repositories\\Presenter\\ManufacturerListPresenter')
                ->scopeQuery(function ($query) {
                    return $query->orderBy('id', 'DESC');
                })->paginate($pageLimit);

            $manufacturers['recordsTotal']    = $manufacturers['meta']['pagination']['total'];
            $manufacturers['recordsFiltered'] = $manufacturers['meta']['pagination']['total'];
            $manufacturers['request']         = $request->all();
            return response()->json($manufacturers, 200);

        }

        $this   ->theme->prependTitle(trans('manufacturer::manufacturer.names').' :: ');
        return $this->theme->of('manufacturer::admin.manufacturer.index')->render();
    }

    /**
     * Display manufacturer.
     *
     * @param Request $request
     * @param Model   $manufacturer
     *
     * @return Response
     */
    public function show(ManufacturerAdminWebRequest $request, Manufacturer $manufacturer)
    {
        if (!$manufacturer->exists) {
            return response()->view('manufacturer::admin.manufacturer.new', compact('manufacturer'));
        }

        Form::populate($manufacturer);
        return response()->view('manufacturer::admin.manufacturer.show', compact('manufacturer'));
    }

    /**
     * Show the form for creating a new manufacturer.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(ManufacturerAdminWebRequest $request)
    {

        $manufacturer = $this->repository->newInstance([]);

        Form::populate($manufacturer);

        return response()->view('manufacturer::admin.manufacturer.create', compact('manufacturer'));

    }

    /**
     * Create new manufacturer.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(ManufacturerAdminWebRequest $request)
    {
        try {
            $attributes             = $request->all();
            $attributes['user_id']  = user_id('admin.web');
            $manufacturer          = $this->repository->create($attributes);

            return response()->json([
                'message'  => trans('messages.success.updated', ['Module' => trans('manufacturer::manufacturer.name')]),
                'code'     => 204,
                'redirect' => trans_url('/admin/manufacturer/manufacturer/'.$manufacturer->getRouteKey())
            ], 201);


        } catch (Exception $e) {
            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
            ], 400);
        }
    }

    /**
     * Show manufacturer for editing.
     *
     * @param Request $request
     * @param Model   $manufacturer
     *
     * @return Response
     */
    public function edit(ManufacturerAdminWebRequest $request, Manufacturer $manufacturer)
    {
        Form::populate($manufacturer);
        return  response()->view('manufacturer::admin.manufacturer.edit', compact('manufacturer'));
    }

    /**
     * Update the manufacturer.
     *
     * @param Request $request
     * @param Model   $manufacturer
     *
     * @return Response
     */
    public function update(ManufacturerAdminWebRequest $request, Manufacturer $manufacturer)
    {
        try {

            $attributes = $request->all();

            $manufacturer->update($attributes);

            return response()->json([
                'message'  => trans('messages.success.updated', ['Module' => trans('manufacturer::manufacturer.name')]),
                'code'     => 204,
                'redirect' => trans_url('/admin/manufacturer/manufacturer/'.$manufacturer->getRouteKey())
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/manufacturer/manufacturer/'.$manufacturer->getRouteKey()),
            ], 400);

        }
    }

    /**
     * Remove the manufacturer.
     *
     * @param Model   $manufacturer
     *
     * @return Response
     */
    public function destroy(ManufacturerAdminWebRequest $request, Manufacturer $manufacturer)
    {

        try {

            $t = $manufacturer->delete();

            return response()->json([
                'message'  => trans('messages.success.deleted', ['Module' => trans('manufacturer::manufacturer.name')]),
                'code'     => 202,
                'redirect' => trans_url('/admin/manufacturer/manufacturer/0'),
            ], 202);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/manufacturer/manufacturer/'.$manufacturer->getRouteKey()),
            ], 400);
        }
    }
}
