<?php

namespace Assetdocs\Manufacturer\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Form;
use Assetdocs\Manufacturer\Http\Requests\ManufacturerUserWebRequest;
use Assetdocs\Manufacturer\Interfaces\ManufacturerRepositoryInterface;
use Assetdocs\Manufacturer\Models\Manufacturer;

class ManufacturerUserController extends BaseController
{
    /**
     * The authentication guard that should be used.
     *
     * @var string
     */
    protected $guard = 'web';

    /**
     * Initialize manufacturer controller.
     *
     * @param type ManufacturerRepositoryInterface $manufacturer
     *
     * @return type
     */
    public function __construct(ManufacturerRepositoryInterface $manufacturer)
    {
        $this->middleware('web');
        $this->middleware('auth:web');
        $this->setupTheme(config('theme.themes.user.theme'), config('theme.themes.user.layout'));

        $this->repository = $manufacturer;
        parent::__construct();
    }

    /**
     * Display a listing of the resource.
     *
     * @return Response
     */
    public function index(ManufacturerUserWebRequest $request)
    {
        $this->repository->pushCriteria(new \Assetdocs\Manufacturer\Repositories\Criteria\ManufacturerUserCriteria());
        $manufacturers = $this->repository->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();

        $this->theme->prependTitle(trans('manufacturer::manufacturer.names').' :: ');

        return $this->theme->of('manufacturer::user.manufacturer.index', compact('manufacturers'))->render();
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     * @param Manufacturer $manufacturer
     *
     * @return Response
     */
    public function show(ManufacturerUserWebRequest $request, Manufacturer $manufacturer)
    {
        Form::populate($manufacturer);

        return $this->theme->of('manufacturer::user.manufacturer.show', compact('manufacturer'))->render();
    }

    /**
     * Show the form for creating a new resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(ManufacturerUserWebRequest $request)
    {

        $manufacturer = $this->repository->newInstance([]);
        Form::populate($manufacturer);

        return $this->theme->of('manufacturer::user.manufacturer.create', compact('manufacturer'))->render();
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(ManufacturerUserWebRequest $request)
    {
        try {
            $attributes = $request->all();
            $attributes['user_id'] = user_id();
            $manufacturer = $this->repository->create($attributes);

            return redirect(trans_url('/user/manufacturer/manufacturer'))
                -> with('message', trans('messages.success.created', ['Module' => trans('manufacturer::manufacturer.name')]))
                -> with('code', 201);

        } catch (Exception $e) {
            redirect()->back()->withInput()->with('message', $e->getMessage())->with('code', 400);
        }
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param Request $request
     * @param Manufacturer $manufacturer
     *
     * @return Response
     */
    public function edit(ManufacturerUserWebRequest $request, Manufacturer $manufacturer)
    {

        Form::populate($manufacturer);

        return $this->theme->of('manufacturer::user.manufacturer.edit', compact('manufacturer'))->render();
    }

    /**
     * Update the specified resource.
     *
     * @param Request $request
     * @param Manufacturer $manufacturer
     *
     * @return Response
     */
    public function update(ManufacturerUserWebRequest $request, Manufacturer $manufacturer)
    {
        try {
            $this->repository->update($request->all(), $manufacturer->getRouteKey());

            return redirect(trans_url('/user/manufacturer/manufacturer'))
                ->with('message', trans('messages.success.updated', ['Module' => trans('manufacturer::manufacturer.name')]))
                ->with('code', 204);

        } catch (Exception $e) {
            redirect()->back()->withInput()->with('message', $e->getMessage())->with('code', 400);
        }
    }

    /**
     * Remove the specified resource.
     *
     * @param int $id
     *
     * @return Response
     */
    public function destroy(ManufacturerUserWebRequest $request, Manufacturer $manufacturer)
    {
        try {
            $this->repository->delete($manufacturer->getRouteKey());
            return response()->json([
                'message'  => trans('messages.success.deleted', ['Module' => trans('manufacturer::manufacturer.name')]),
                'code'     => 202,
                'redirect' => trans_url('/user/manufacturer/manufacturer/0'),
            ], 202);

        } catch (Exception $e) {

            redirect()->back()->withInput()->with('message', $e->getMessage())->with('code', 400);

        }
    }
}
